#include "printpreview.h"
#include <QTextCodec>
#include <QFile>
#include <QPrinter>

#include <QDebug>
#include <QPrintDialog>
#include <QToolBar>
#include <QLineEdit>
#include <QLabel>

#include "qprintpreviewwidget.h"


CPrintPreview::CPrintPreview(QWidget *parent, Qt::WFlags flags)
	: QMainWindow(parent, flags), m_printer(0)
{
	ui.setupUi(this);

	m_printer = new QPrinter(QPrinter::ScreenResolution);

    QVBoxLayout* vboxLayout2X = new QVBoxLayout(ui.tab_2);

	{
		QToolBar* toolBar = new QToolBar(ui.tab_2);

		m_scaleEdit = new QLineEdit;
		m_scaleEdit->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
		m_scaleEdit->setReadOnly(true);
		toolBar->addWidget(m_scaleEdit);

		QSizePolicy sp = toolBar->sizePolicy();
		sp.setVerticalPolicy(QSizePolicy::Fixed);
		toolBar->setSizePolicy(sp);
		vboxLayout2X->addWidget(toolBar);

		toolBar->addAction(tr("Zoom In"), this, SLOT(onPreviewZoomIn()));
		toolBar->addAction(tr("Zoom Out"), this, SLOT(onPreviewZoomOut()));
		toolBar->addSeparator();

		m_pageNumber = new QLineEdit;
		m_pageNumber->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
		m_pageNumber->setReadOnly(true);

		toolBar->addAction(tr("Prev page"), this, SLOT(onPrevPage()));
		toolBar->addWidget(m_pageNumber);
		toolBar->addAction(tr("Next page"), this, SLOT(onNextPage()));

		if(toolBar->layout())
		{
			toolBar->layout()->addItem(new QSpacerItem(10, 10, QSizePolicy::Expanding));
			toolBar->layout();
//			; add Widget(new QLabel("|"));
		}
	}

//	ui.tab_2->setLayout(0);
	m_preview = new QPrintPreviewWidget(ui.tab_2);
	m_preview->setPrinter(m_printer);

    vboxLayout2X->addWidget(m_preview);


	connect(ui.act_preview, SIGNAL(triggered()), this, SLOT(onPreview()));

    if (!load("example.html"))
		Q_ASSERT(true);

	m_preview->setDocument(ui.textEdit->document());
	m_preview->setScale(60);

	updateScaleEdit();
	resize(600, 500);
}

CPrintPreview::~CPrintPreview()
{
	m_preview->setPrinter(0);
	m_preview->setDocument(0);

	delete m_printer;
	m_printer = 0;
}

void CPrintPreview::updateScaleEdit()
{
	m_scaleEdit->setText(QString::number(m_preview->scale())+'%');
	m_pageNumber->setText( tr("Page %1 of %2").arg(m_preview->pageIndex()+1).arg(m_preview->pageCount()) );
}

void CPrintPreview::onPreviewZoomIn()
{
	m_preview->setScale(m_preview->scale()+10);
	updateScaleEdit();
}

void CPrintPreview::onPreviewZoomOut()
{
	m_preview->setScale(m_preview->scale()-10);
	updateScaleEdit();
}

void CPrintPreview::onPrevPage()
{
	m_preview->setPageIndex(m_preview->pageIndex() - 1);
	updateScaleEdit();
}

void CPrintPreview::onNextPage()
{
	m_preview->setPageIndex(m_preview->pageIndex() + 1);
	updateScaleEdit();
}

bool CPrintPreview::load(const QString &f)
{
    if (!QFile::exists(f))
        return false;
    QFile file(f);
    if (!file.open(QFile::ReadOnly))
        return false;

    QByteArray data = file.readAll();
    QTextCodec *codec = Qt::codecForHtml(data);
    QString str = codec->toUnicode(data);
    if (Qt::mightBeRichText(str)) {
        ui.textEdit->setHtml(str);
    } else {
        str = QString::fromLocal8Bit(data);
        ui.textEdit->setPlainText(str);
    }

    return true;
}

void CPrintPreview::onPreview()
{
	{
		m_printer->setFullPage(true);
		QPrintDialog dlg(m_printer, this);
		if (dlg.exec() != QDialog::Accepted) 
			return;
	}
	m_printer->setFromTo(1, 1);
	
	m_preview->setDocument(ui.textEdit->document());
	m_preview->updatePreview();
	updateScaleEdit();


//	ui.textEdit->document()->print(&printer);

/*
//	210x297
//	QPixmap pix(210*2, 297*2);
	QPixmap pix(printer.width(), printer.height());

	printer.setFromTo(1, 1);
	printPix(ui.textEdit->document(), &printer, &pix);
	lb_preview->setPixmap(pix);
	lb_preview->resize(pix.size());
*/
}
